==> haskell-hls-explicit-fixity-plugin-2.1.0.0-85-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-fixity-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-fixity-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-explicit-fixity-plugin-2.1.0.0-JzqmDJR6qhLGChoqmDb3Ru
key:                  hls-explicit-fixity-plugin-2.1.0.0-JzqmDJR6qhLGChoqmDb3Ru
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Show fixity explicitly while hovering
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-explicit-fixity-plugin#readme>

category:             Development
abi:                  d7b73aac4fc8ac1b4996c7d06f55700e
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFixity
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-fixity-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-fixity-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-fixity-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-fixity-plugin
hs-libraries:         HShls-explicit-fixity-plugin-2.1.0.0-JzqmDJR6qhLGChoqmDb3Ru
depends:
    base-4.17.2.1 containers-0.6.7 deepseq-1.4.8.0
    extra-1.7.16-4PSPnwgFT0S5iaiPzXfiD0 ghc-9.4.8
    ghcide-2.1.0.0-FzPM2kBc4xorjD0nKMMOc
    hashable-1.4.7.0-GgneweRn8eTKcMM4X3n956
    hls-plugin-api-2.1.0.0-IF2mjrMBh4aKpRc7AO1ZaH
    lsp-2.1.0.0-JRAvMRSrlV11n1YRb0fu3x text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-fixity-plugin/html/hls-explicit-fixity-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-explicit-fixity-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-explicit-fixity-plugin-2.1.0.0-86-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-fixity-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-fixity-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-explicit-fixity-plugin-2.1.0.0-KWv3ZcubxGR3tSmW2sy8U1
key:                  hls-explicit-fixity-plugin-2.1.0.0-KWv3ZcubxGR3tSmW2sy8U1
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Show fixity explicitly while hovering
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-explicit-fixity-plugin#readme>

category:             Development
abi:                  238b1febf9bb0cff5e4eaa0f888e6503
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFixity
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-fixity-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-fixity-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-fixity-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-fixity-plugin
hs-libraries:         HShls-explicit-fixity-plugin-2.1.0.0-KWv3ZcubxGR3tSmW2sy8U1
depends:
    base-4.17.2.1 containers-0.6.7 deepseq-1.4.8.0
    extra-1.7.16-4PSPnwgFT0S5iaiPzXfiD0 ghc-9.4.8
    ghcide-2.1.0.0-CWfzxxGoecT4KeQoxwUUIF
    hashable-1.4.7.0-GgneweRn8eTKcMM4X3n956
    hls-plugin-api-2.1.0.0-LlZjhMMNQE77OsdPFnp44U
    lsp-2.1.0.0-JRAvMRSrlV11n1YRb0fu3x text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-fixity-plugin/html/hls-explicit-fixity-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-explicit-fixity-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
